# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from ai_assistant_server_connector.models.ai_assistant_get import AiAssistantGet
from ai_assistant_server_connector.models.emphemeral_credentials import EmphemeralCredentials

class AIAssistantSessionStart(BaseModel):
    """
    AIAssistantSessionStart
    """
    ai_assistant: AiAssistantGet = Field(...)
    credentials: EmphemeralCredentials = Field(...)
    __properties = ["ai_assistant", "credentials"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AIAssistantSessionStart:
        """Create an instance of AIAssistantSessionStart from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of ai_assistant
        if self.ai_assistant:
            _dict['ai_assistant'] = self.ai_assistant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of credentials
        if self.credentials:
            _dict['credentials'] = self.credentials.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AIAssistantSessionStart:
        """Create an instance of AIAssistantSessionStart from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AIAssistantSessionStart.parse_obj(obj)

        _obj = AIAssistantSessionStart.parse_obj({
            "ai_assistant": AiAssistantGet.from_dict(obj.get("ai_assistant")) if obj.get("ai_assistant") is not None else None,
            "credentials": EmphemeralCredentials.from_dict(obj.get("credentials")) if obj.get("credentials") is not None else None
        })
        return _obj


