# coding: utf-8

# flake8: noqa

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.3.1+2484675028"

# Define package exports
__all__ = [
    "AiAssistantApiApi",
    "AssistantsApi",
    "AssistantsServerApi",
    "AvatarsApi",
    "DefaultApi",
    "GoalEngagementPresetsApi",
    "RagApi",
    "ServerApi",
    "VoicesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AIAssistantReponseStreamRequest",
    "AIAssistantSessionStart",
    "AiAssistantCustomSkillCreate",
    "AiAssistantCustomSkillGet",
    "AiAssistantCustomSkillPatch",
    "AiAssistantCustomSkillUpdate",
    "AiAssistantGet",
    "AiAssistantGoalCreate",
    "AiAssistantGoalCreateUpdate",
    "AiAssistantGoalGet",
    "AiAssistantLexiconItem",
    "AiAssistantLexiconItemCreateOrUpdate",
    "AiAssistantLexiconItemNew",
    "AiAssistantListGet",
    "AiAssistantNew",
    "AiAssistantSettingToggle",
    "AiAssistantSetupFromRoot",
    "AiAssistantSkillSettingGet",
    "AiAssistantToolSettingGet",
    "AiAssistantUpdate",
    "AssistantFunction",
    "AvatarOptionGet",
    "ChatHistoryChatContent",
    "ChatHistoryItem",
    "ChatMessageAttachment",
    "ChatMessageAttachmentType",
    "ChatRole",
    "CollectionState",
    "CollectionStatus",
    "ConversationStyle",
    "CourseModulePublic",
    "CoursePaymentTypeStrEnum",
    "CoursePublic",
    "EmphemeralCredentials",
    "GoalEngagementPresetGet",
    "GoalInteractionsSummary",
    "HTTPValidationError",
    "InteractionType",
    "KnowledgebaseState",
    "LanguageStrEnum",
    "LocationInner",
    "ModuleLessonPublic",
    "PortalInfoRequest",
    "PortalOwnerInfo",
    "RagQueryResponse",
    "ResponseChunk",
    "ResponseChunkType",
    "ResponseWrapper",
    "ResponseWrapperAIAssistantSessionStart",
    "ResponseWrapperAiAssistantGet",
    "ResponseWrapperBool",
    "ResponseWrapperInt",
    "ResponseWrapperListAiAssistantCustomSkillGet",
    "ResponseWrapperListAiAssistantGoalGet",
    "ResponseWrapperListAiAssistantListGet",
    "ResponseWrapperListAiAssistantSkillSettingGet",
    "ResponseWrapperListAiAssistantToolSettingGet",
    "ResponseWrapperListAvatarOptionGet",
    "ResponseWrapperListGoalEngagementPresetGet",
    "ResponseWrapperListVoiceOptionGet",
    "ResponseWrapperRagQueryResponse",
    "Result",
    "Score",
    "SearchResult",
    "UsageDetails",
    "UserGoalInteractionCreate",
    "ValidationError",
    "VoiceOptionGet",
]

# import apis into sdk package
from ai_assistant_server_connector.api.ai_assistant_api_api import AiAssistantApiApi as AiAssistantApiApi
from ai_assistant_server_connector.api.assistants_api import AssistantsApi as AssistantsApi
from ai_assistant_server_connector.api.assistants_server_api import AssistantsServerApi as AssistantsServerApi
from ai_assistant_server_connector.api.avatars_api import AvatarsApi as AvatarsApi
from ai_assistant_server_connector.api.default_api import DefaultApi as DefaultApi
from ai_assistant_server_connector.api.goal_engagement_presets_api import GoalEngagementPresetsApi as GoalEngagementPresetsApi
from ai_assistant_server_connector.api.rag_api import RagApi as RagApi
from ai_assistant_server_connector.api.server_api import ServerApi as ServerApi
from ai_assistant_server_connector.api.voices_api import VoicesApi as VoicesApi

# import ApiClient
from ai_assistant_server_connector.api_response import ApiResponse as ApiResponse
from ai_assistant_server_connector.api_client import ApiClient as ApiClient
from ai_assistant_server_connector.configuration import Configuration as Configuration
from ai_assistant_server_connector.exceptions import OpenApiException as OpenApiException
from ai_assistant_server_connector.exceptions import ApiTypeError as ApiTypeError
from ai_assistant_server_connector.exceptions import ApiValueError as ApiValueError
from ai_assistant_server_connector.exceptions import ApiKeyError as ApiKeyError
from ai_assistant_server_connector.exceptions import ApiAttributeError as ApiAttributeError
from ai_assistant_server_connector.exceptions import ApiException as ApiException

# import models into sdk package
from ai_assistant_server_connector.models.ai_assistant_reponse_stream_request import AIAssistantReponseStreamRequest as AIAssistantReponseStreamRequest
from ai_assistant_server_connector.models.ai_assistant_session_start import AIAssistantSessionStart as AIAssistantSessionStart
from ai_assistant_server_connector.models.ai_assistant_custom_skill_create import AiAssistantCustomSkillCreate as AiAssistantCustomSkillCreate
from ai_assistant_server_connector.models.ai_assistant_custom_skill_get import AiAssistantCustomSkillGet as AiAssistantCustomSkillGet
from ai_assistant_server_connector.models.ai_assistant_custom_skill_patch import AiAssistantCustomSkillPatch as AiAssistantCustomSkillPatch
from ai_assistant_server_connector.models.ai_assistant_custom_skill_update import AiAssistantCustomSkillUpdate as AiAssistantCustomSkillUpdate
from ai_assistant_server_connector.models.ai_assistant_get import AiAssistantGet as AiAssistantGet
from ai_assistant_server_connector.models.ai_assistant_goal_create import AiAssistantGoalCreate as AiAssistantGoalCreate
from ai_assistant_server_connector.models.ai_assistant_goal_create_update import AiAssistantGoalCreateUpdate as AiAssistantGoalCreateUpdate
from ai_assistant_server_connector.models.ai_assistant_goal_get import AiAssistantGoalGet as AiAssistantGoalGet
from ai_assistant_server_connector.models.ai_assistant_lexicon_item import AiAssistantLexiconItem as AiAssistantLexiconItem
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_create_or_update import AiAssistantLexiconItemCreateOrUpdate as AiAssistantLexiconItemCreateOrUpdate
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_new import AiAssistantLexiconItemNew as AiAssistantLexiconItemNew
from ai_assistant_server_connector.models.ai_assistant_list_get import AiAssistantListGet as AiAssistantListGet
from ai_assistant_server_connector.models.ai_assistant_new import AiAssistantNew as AiAssistantNew
from ai_assistant_server_connector.models.ai_assistant_setting_toggle import AiAssistantSettingToggle as AiAssistantSettingToggle
from ai_assistant_server_connector.models.ai_assistant_setup_from_root import AiAssistantSetupFromRoot as AiAssistantSetupFromRoot
from ai_assistant_server_connector.models.ai_assistant_skill_setting_get import AiAssistantSkillSettingGet as AiAssistantSkillSettingGet
from ai_assistant_server_connector.models.ai_assistant_tool_setting_get import AiAssistantToolSettingGet as AiAssistantToolSettingGet
from ai_assistant_server_connector.models.ai_assistant_update import AiAssistantUpdate as AiAssistantUpdate
from ai_assistant_server_connector.models.assistant_function import AssistantFunction as AssistantFunction
from ai_assistant_server_connector.models.avatar_option_get import AvatarOptionGet as AvatarOptionGet
from ai_assistant_server_connector.models.chat_history_chat_content import ChatHistoryChatContent as ChatHistoryChatContent
from ai_assistant_server_connector.models.chat_history_item import ChatHistoryItem as ChatHistoryItem
from ai_assistant_server_connector.models.chat_message_attachment import ChatMessageAttachment as ChatMessageAttachment
from ai_assistant_server_connector.models.chat_message_attachment_type import ChatMessageAttachmentType as ChatMessageAttachmentType
from ai_assistant_server_connector.models.chat_role import ChatRole as ChatRole
from ai_assistant_server_connector.models.collection_state import CollectionState as CollectionState
from ai_assistant_server_connector.models.collection_status import CollectionStatus as CollectionStatus
from ai_assistant_server_connector.models.conversation_style import ConversationStyle as ConversationStyle
from ai_assistant_server_connector.models.course_module_public import CourseModulePublic as CourseModulePublic
from ai_assistant_server_connector.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum as CoursePaymentTypeStrEnum
from ai_assistant_server_connector.models.course_public import CoursePublic as CoursePublic
from ai_assistant_server_connector.models.emphemeral_credentials import EmphemeralCredentials as EmphemeralCredentials
from ai_assistant_server_connector.models.goal_engagement_preset_get import GoalEngagementPresetGet as GoalEngagementPresetGet
from ai_assistant_server_connector.models.goal_interactions_summary import GoalInteractionsSummary as GoalInteractionsSummary
from ai_assistant_server_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from ai_assistant_server_connector.models.interaction_type import InteractionType as InteractionType
from ai_assistant_server_connector.models.knowledgebase_state import KnowledgebaseState as KnowledgebaseState
from ai_assistant_server_connector.models.language_str_enum import LanguageStrEnum as LanguageStrEnum
from ai_assistant_server_connector.models.location_inner import LocationInner as LocationInner
from ai_assistant_server_connector.models.module_lesson_public import ModuleLessonPublic as ModuleLessonPublic
from ai_assistant_server_connector.models.portal_info_request import PortalInfoRequest as PortalInfoRequest
from ai_assistant_server_connector.models.portal_owner_info import PortalOwnerInfo as PortalOwnerInfo
from ai_assistant_server_connector.models.rag_query_response import RagQueryResponse as RagQueryResponse
from ai_assistant_server_connector.models.response_chunk import ResponseChunk as ResponseChunk
from ai_assistant_server_connector.models.response_chunk_type import ResponseChunkType as ResponseChunkType
from ai_assistant_server_connector.models.response_wrapper import ResponseWrapper as ResponseWrapper
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_session_start import ResponseWrapperAIAssistantSessionStart as ResponseWrapperAIAssistantSessionStart
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_get import ResponseWrapperAiAssistantGet as ResponseWrapperAiAssistantGet
from ai_assistant_server_connector.models.response_wrapper_bool import ResponseWrapperBool as ResponseWrapperBool
from ai_assistant_server_connector.models.response_wrapper_int import ResponseWrapperInt as ResponseWrapperInt
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_custom_skill_get import ResponseWrapperListAiAssistantCustomSkillGet as ResponseWrapperListAiAssistantCustomSkillGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_goal_get import ResponseWrapperListAiAssistantGoalGet as ResponseWrapperListAiAssistantGoalGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_list_get import ResponseWrapperListAiAssistantListGet as ResponseWrapperListAiAssistantListGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_skill_setting_get import ResponseWrapperListAiAssistantSkillSettingGet as ResponseWrapperListAiAssistantSkillSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_tool_setting_get import ResponseWrapperListAiAssistantToolSettingGet as ResponseWrapperListAiAssistantToolSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_avatar_option_get import ResponseWrapperListAvatarOptionGet as ResponseWrapperListAvatarOptionGet
from ai_assistant_server_connector.models.response_wrapper_list_goal_engagement_preset_get import ResponseWrapperListGoalEngagementPresetGet as ResponseWrapperListGoalEngagementPresetGet
from ai_assistant_server_connector.models.response_wrapper_list_voice_option_get import ResponseWrapperListVoiceOptionGet as ResponseWrapperListVoiceOptionGet
from ai_assistant_server_connector.models.response_wrapper_rag_query_response import ResponseWrapperRagQueryResponse as ResponseWrapperRagQueryResponse
from ai_assistant_server_connector.models.result import Result as Result
from ai_assistant_server_connector.models.score import Score as Score
from ai_assistant_server_connector.models.search_result import SearchResult as SearchResult
from ai_assistant_server_connector.models.usage_details import UsageDetails as UsageDetails
from ai_assistant_server_connector.models.user_goal_interaction_create import UserGoalInteractionCreate as UserGoalInteractionCreate
from ai_assistant_server_connector.models.validation_error import ValidationError as ValidationError
from ai_assistant_server_connector.models.voice_option_get import VoiceOptionGet as VoiceOptionGet
