# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector.api.server_api import ServerApi  # noqa: E501


class TestServerApi(unittest.IsolatedAsyncioTestCase):
    """ServerApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ServerApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_ai_assistant_api_server_assistant_list(self) -> None:
        """Test case for ai_assistant_api_server_assistant_list

        Server Assistant List  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_server_assistant_setup_from_root(self) -> None:
        """Test case for ai_assistant_api_server_assistant_setup_from_root

        Server Assistant Setup From Root  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
